Welcome to Kivy — Kivy v1.0.1-dev documentation

# Welcome to Kivy

Welcome to Kivy’s documentation. Kivy is an open source software library for rapid development of applications equipped with novel user interfaces, such as multi-touch apps.

You are probably wondering why you’d be interested in using Kivy. There is a document outlining our Philosophy that we encourage you to read.

We recommend that you get started with Installation and then head over to the Quickstart document. Besides the quickstart, there is also a more detailed Architectural Overview.

If you want to contribute to Kivy, make sure to read Contributing. If your concern isn’t addressed in the documentation, feel free to Contact Us.

## User’s Guide

This part of the documentation explains the basic ideas behind Kivy’s design and why you’d want to use it. It goes on with a discussion of the architecture and shows you how to create stunning applications in short time using the framework.

- Philosophy
  - Why bother?
- Programming Guide
  - Installation
  - Quickstart
  - Architectural Overview
  - Running on mobile platform
- Contributing
  - Code Contributions
  - Documentation Contributions
- Frequently Asked Questions
  - Why do you use Python? Isn’t it slow?
  - Does Kivy support Python 3.x?
  - How is Kivy related to PyMT?
  - Do you accept patches?
  - Does the Kivy project participate in Google’s Summer of Code 2011?
- Contact Us
  - Issue Tracker
  - Mail
  - IRC

## API Reference

The API reference is a lexicographic list of all the different classes, methods and features that Kivy offers.

- Kivy framework
  - Animation
  - Application
  - Event loop management
  - Cache manager
  - Clock object
  - Configuration object
  - Event dispatcher
  - Factory object
  - Gesture recognition
  - Kivy language
  - Asynchronous data loader
  - Logger object
  - Properties
  - Resources management
  - Utils
  - Vector
  - Weak Method
- Core Abstraction
  - Audio
  - Camera
  - Clipboard
  - OpenGL
  - Image
  - Spelling
  - SVG
  - Text
  - Video
  - Window
- Graphics
  - The basics
  - Compilation
  - Graphics compiler
  - Context instructions
  - Framebuffer
  - Canvas
  - Texture management
  - Transformation
  - Vertex Instructions
- Input management
  - Input Postprocessing
  - Providers
  - Motion Event Factory
  - Motion Event
  - Motion Event Provider
  - Motion Event Shape
- Modules
- UIX
  - Anchor layout
  - Box Layout
  - Button
  - Camera
  - Float Layout
  - Image
  - Label
  - Layout
  - Scatter
  - Slider
  - Toggle button
  - Video
  - Widget class

# Indices and tables

- Index
- Module Index
- Search Page